@@ -17,6 +17,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <libecal/e-cal-component.h>
+#include "sunone-util.h"
 #include "sunone-message.h"
 
 gboolean jescs_verbose_debug = FALSE;
@@ -132,7 +133,7 @@ parse_server_response (SoupMessage *msg, SoupStatusClass *error_class)
 
 	g_return_if_fail (msg->response.body != NULL);
 
-	icalcomp = icalparser_parse_string (msg->response.body);
+	icalcomp = sunone_util_icalparser_parse_string (msg->response.body, msg->response.length);
 	if (icalcomp) {
 		icalprop = icalcomponent_get_first_property (icalcomp, ICAL_X_PROPERTY);
 		while (icalprop) {
