@@ -295,19 +295,19 @@ add_source (SunOneAccount *account, const char *calid, const char *display_name,
 	char *physical_uri;
 
 	if (personal) {
-		physical_uri = sunone_util_get_physical_uri_from_account (account, calid, "calendar");
+		physical_uri = sunone_account_get_physical_uri (account, calid, "calendar");
 		add_esource (account, _("Personal Calendar"), physical_uri, &source_list_cal);
 		g_free (physical_uri);
 
-		physical_uri = sunone_util_get_physical_uri_from_account (account, calid, "tasks");
+		physical_uri = sunone_account_get_physical_uri (account, calid, "tasks");
 		add_esource (account, _("Personal Task"), physical_uri, &source_list_task);
 		g_free (physical_uri);
 	} else {
-		physical_uri = sunone_util_get_physical_uri_from_account (account, calid, "calendar");
+		physical_uri = sunone_account_get_physical_uri (account, calid, "calendar");
 		add_esource (account, display_name, physical_uri, &source_list_cal);
 		g_free (physical_uri);
 
-		physical_uri = sunone_util_get_physical_uri_from_account (account, calid, "tasks");
+		physical_uri = sunone_account_get_physical_uri (account, calid, "tasks");
 		add_esource (account, display_name, physical_uri, &source_list_task);
 		g_free (physical_uri);
 	}
@@ -330,7 +330,6 @@ remove_unused_sources(SunOneAccount *account, SunOneConnectionPreferences *prefe
 		for (sources = e_source_group_peek_sources (group); sources != NULL; sources = sources->next) {
 			ESource *source = E_SOURCE (sources->data);
 			GList *prefs;
-			char *physical_uri;
 
 			if (!source)
 				continue;
@@ -357,7 +356,6 @@ remove_unused_sources(SunOneAccount *account, SunOneConnectionPreferences *prefe
 		for (sources = e_source_group_peek_sources (group); sources != NULL; sources = sources->next) {
 			ESource *source = E_SOURCE (sources->data);
 			GList *prefs;
-			char *physical_uri;
 
 			if (!source)
 				continue;
@@ -399,11 +397,11 @@ add_sources (SunOneAccount *account, SunOneConnectionPreferences *prefs)
 
 		calid = sub->calid;
 		display_name = sub->display_name && *(sub->display_name) ? sub->display_name : sub->calid;
-		physical_uri = sunone_util_get_physical_uri_from_account (account, calid, "calendar");
+		physical_uri = sunone_account_get_physical_uri (account, calid, "calendar");
 		add_esource (account, display_name, physical_uri, &source_list_cal);
 		g_free (physical_uri);
 
-		physical_uri = sunone_util_get_physical_uri_from_account (account, calid, "tasks");
+		physical_uri = sunone_account_get_physical_uri (account, calid, "tasks");
 		add_esource (account, display_name, physical_uri, &source_list_task);
 		g_free (physical_uri);
 	}
@@ -414,11 +412,11 @@ remove_source (SunOneAccount *account, const char *calid, gboolean is_account)
 {
 	char *physical_uri;
 
-	physical_uri = sunone_util_get_physical_uri_from_account (account, calid, "calendar");
+	physical_uri = sunone_account_get_physical_uri (account, calid, "calendar");
 	remove_esource (account, physical_uri, &source_list_cal, is_account);
 	g_free (physical_uri);
 
-	physical_uri = sunone_util_get_physical_uri_from_account (account, calid, "tasks");
+	physical_uri = sunone_account_get_physical_uri (account, calid, "tasks");
 	remove_esource (account, physical_uri, &source_list_task, is_account);
 	g_free (physical_uri);
 }
@@ -428,11 +426,11 @@ rename_source (SunOneAccount *account, const char *calid, const char *display_na
 {
 	char *physical_uri;
 
-	physical_uri = sunone_util_get_physical_uri_from_account (account, calid, "calendar");
+	physical_uri = sunone_account_get_physical_uri (account, calid, "calendar");
 	rename_esource (account, display_name, physical_uri, &source_list_cal);
 	g_free (physical_uri);
 
-	physical_uri = sunone_util_get_physical_uri_from_account (account, calid, "tasks");
+	physical_uri = sunone_account_get_physical_uri (account, calid, "tasks");
 	rename_esource (account, display_name, physical_uri, &source_list_task);
 	g_free (physical_uri);
 }
